@@ -7,26 +7,24 @@ import re
 import sys
 import warnings
 from contextlib import contextmanager
-from functools import partial, wraps
+from functools import partial
 from importlib.metadata import version as pkgversion
 from pathlib import Path
 from random import sample
 from tempfile import gettempdir
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING
 
 from duty import duty, tools
 from pysource_codegen import generate
 from pysource_minimize import minimize
 
-from griffe import visit
-
 if TYPE_CHECKING:
-    from collections.abc import Callable, Iterator
+    from collections.abc import Iterator
 
     from duty.context import Context
 
 
-PY_SRC_PATHS = (Path(_) for _ in ("src", "tests", "duties.py", "scripts"))
+PY_SRC_PATHS = (Path(_) for _ in ("packages/griffecli/src", "packages/griffelib/src", "tests", "duties.py", "scripts"))
 PY_SRC_LIST = tuple(str(_) for _ in PY_SRC_PATHS)
 PY_SRC = " ".join(PY_SRC_LIST)
 CI = os.environ.get("CI", "0") in {"1", "true", "yes", ""}
@@ -44,21 +42,6 @@ def _pyprefix(title: str) -> str:
     return title
 
 
-def _not_from_insiders(func: Callable) -> Callable:
-    @wraps(func)
-    def wrapper(ctx: Context, *args: Any, **kwargs: Any) -> None:
-        origin = ctx.run("git config --get remote.origin.url", silent=True)
-        if "pawamoy-insiders/griffe" in origin:
-            ctx.run(
-                lambda: False,
-                title="Not running this task from insiders repository (do that from public repo instead!)",
-            )
-            return
-        func(ctx, *args, **kwargs)
-
-    return wrapper
-
-
 @contextmanager
 def _material_insiders() -> Iterator[bool]:
     if "+insiders" in pkgversion("mkdocs-material"):
@@ -304,12 +287,27 @@ def check_api(ctx: Context, *cli_args: str) -> None:
     ctx.run(
         tools.griffe.check(
             "griffe",
-            search=["src"],
+            search=["packages/griffelib/src"],
             color=True,
-            # YORE: Bump 2: Remove line.
-            extensions=["scripts/griffe_exts.py"],
+            extensions=[
+                "griffe_inherited_docstrings",
+                "unpack_typeddict",
+            ],
         ).add_args(*cli_args),
-        title="Checking for API breaking changes",
+        title="Checking for API breaking changes in Griffe library",
+        nofail=True,
+    )
+    ctx.run(
+        tools.griffe.check(
+            "griffecli",
+            search=["packages/griffecli/src"],
+            color=True,
+            extensions=[
+                "griffe_inherited_docstrings",
+                "unpack_typeddict",
+            ],
+        ).add_args(*cli_args),
+        title="Checking for API breaking changes in Griffe CLI",
         nofail=True,
     )
 
@@ -338,7 +336,7 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
 
 
 @duty
-def docs_deploy(ctx: Context, *, force: bool = False) -> None:
+def docs_deploy(ctx: Context) -> None:
     """Deploy the documentation to GitHub pages.
 
     ```bash
@@ -346,37 +344,12 @@ def docs_deploy(ctx: Context, *, force: bool = False) -> None:
     ```
 
     Use [MkDocs](https://www.mkdocs.org/) to build and deploy the documentation to GitHub pages.
-
-    Parameters:
-        force: Whether to force deployment, even from non-Insiders version.
     """
     os.environ["DEPLOY"] = "true"
     with _material_insiders() as insiders:
         if not insiders:
             ctx.run(lambda: False, title="Not deploying docs without Material for MkDocs Insiders!")
-        origin = ctx.run("git config --get remote.origin.url", silent=True, allow_overrides=False)
-        if "pawamoy-insiders/griffe" in origin:
-            ctx.run(
-                "git remote add upstream git@github.com:mkdocstrings/griffe",
-                silent=True,
-                nofail=True,
-                allow_overrides=False,
-            )
-            ctx.run(
-                tools.mkdocs.gh_deploy(remote_name="upstream", force=True),
-                title="Deploying documentation",
-            )
-        elif force:
-            ctx.run(
-                tools.mkdocs.gh_deploy(force=True),
-                title="Deploying documentation",
-            )
-        else:
-            ctx.run(
-                lambda: False,
-                title="Not deploying docs from public repository (do that from insiders instead!)",
-                nofail=True,
-            )
+        ctx.run(tools.mkdocs.gh_deploy(force=True), title="Deploying documentation")
 
 
 @duty
@@ -406,19 +379,16 @@ def build(ctx: Context) -> None:
     ```
 
     Build distributions of your project for the current version.
-    The build task uses the [`build` tool](https://build.pypa.io/en/stable/)
-    to build `.tar.gz` (Gzipped sources archive) and `.whl` (wheel) distributions
-    of your project in the `dist` directory.
+    Distribution files will be created in the `dist` directory.
     """
     ctx.run(
-        tools.build(),
-        title="Building source and wheel distributions",
+        ["uv", "build", "--all"],
+        title="Building package source and wheel distributions",
         pty=PTY,
     )
 
 
 @duty
-@_not_from_insiders
 def publish(ctx: Context) -> None:
     """Publish source and wheel distributions to PyPI.
 
@@ -440,7 +410,6 @@ def publish(ctx: Context) -> None:
 
 
 @duty(post=["build", "publish", "docs-deploy"])
-@_not_from_insiders
 def release(ctx: Context, version: str = "") -> None:
     """Release a new version of the project.
 
@@ -465,7 +434,7 @@ def release(ctx: Context, version: str = "") -> None:
         ctx.run("false", title="A version must be provided")
     ctx.run("git add pyproject.toml CHANGELOG.md", title="Staging files", pty=PTY)
     ctx.run(["git", "commit", "-m", f"chore: Prepare release {version}"], title="Committing changes", pty=PTY)
-    ctx.run(f"git tag {version}", title="Tagging commit", pty=PTY)
+    ctx.run(f"git tag -m '' -a {version}", title="Tagging commit", pty=PTY)
     ctx.run("git push", title="Pushing commits", pty=False)
     ctx.run("git push --tags", title="Pushing tags", pty=False)
 
@@ -488,11 +457,11 @@ def coverage(ctx: Context) -> None:
 
 
 @duty(nofail=PY_VERSION == PY_DEV)
-def test(ctx: Context, *cli_args: str, match: str = "") -> None:  # noqa: PT028
+def test(ctx: Context, *cli_args: str) -> None:
     """Run the test suite.
 
     ```bash
-    make test [match=EXPR]
+    make test
     ```
 
     Run the test suite with [Pytest](https://docs.pytest.org/) and plugins.
@@ -501,14 +470,13 @@ def test(ctx: Context, *cli_args: str, match: str = "") -> None:  # noqa: PT028
 
     Parameters:
         *cli_args: Additional Pytest CLI arguments.
-        match: A pytest expression to filter selected tests.
     """
     os.environ["COVERAGE_FILE"] = f".coverage.{PY_VERSION}"
+    os.environ["PYTHONWARNDEFAULTENCODING"] = "1"
     ctx.run(
         tools.pytest(
             "tests",
             config_file="config/pytest.ini",
-            select=match,
             color="yes",
         ).add_args("-n", "auto", *cli_args),
         title=_pyprefix("Running tests"),
@@ -539,6 +507,8 @@ def fuzz(
         min_seed: Minimum value for the seeds range.
         max_seed: Maximum value for the seeds range.
     """
+    from griffe import visit  # noqa: PLC0415
+
     warnings.simplefilter("ignore", SyntaxWarning)
 
     def fails(code: str, filepath: Path) -> bool:
